==> quintessence-core-0.0.1-sources.jar: net/aequologica/neo/quintessence/aether/Booter.java <==
package net.aequologica.neo.quintessence.aether;

import static net.aequologica.neo.geppaequo.config.ConfigRegistry.getConfig;

import java.io.Closeable;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.maven.repository.internal.MavenRepositorySystemUtils;
import org.eclipse.aether.DefaultRepositorySystemSession;
import org.eclipse.aether.RepositorySystem;
import org.eclipse.aether.RepositorySystemSession;
import org.eclipse.aether.connector.basic.BasicRepositoryConnectorFactory;
import org.eclipse.aether.impl.DefaultServiceLocator;
import org.eclipse.aether.repository.LocalRepository;
import org.eclipse.aether.repository.RemoteRepository;
import org.eclipse.aether.spi.connector.RepositoryConnectorFactory;
import org.eclipse.aether.spi.connector.transport.TransporterFactory;
import org.eclipse.aether.transport.file.FileTransporterFactory;
import org.eclipse.aether.transport.http.HttpTransporterFactory;

import net.aequologica.neo.quintessence.aether.utils.ConsoleRepositoryListener;
import net.aequologica.neo.quintessence.aether.utils.ConsoleTransferListener;
import net.aequologica.neo.quintessence.aether.utils.TempDirectory;
import net.aequologica.neo.quintessence.config.QuintessenceConfig;

public class Booter implements Closeable {

    final private TempDirectory tempDirectory;
    
    public Booter() throws IOException {
        super();
        this.tempDirectory = new TempDirectory("local-repo");
    }

    public RepositorySystem newRepositorySystem() {
        /*
         * Aether's components implement org.eclipse.aether.spi.locator.Service
         * to ease manual wiring and using the prepopulated
         * DefaultServiceLocator, we only need to register the repository
         * connector and transporter factories.
         */
        DefaultServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        locator.addService(RepositoryConnectorFactory.class, BasicRepositoryConnectorFactory.class);
        locator.addService(TransporterFactory.class, FileTransporterFactory.class);
        locator.addService(TransporterFactory.class, HttpTransporterFactory.class);

        locator.setErrorHandler(new DefaultServiceLocator.ErrorHandler() {
            @Override
            public void serviceCreationFailed(Class<?> type, Class<?> impl, Throwable exception) {
                exception.printStackTrace();
            }
        });

        return locator.getService(RepositorySystem.class);
    }    

    public DefaultRepositorySystemSession newRepositorySystemSession(RepositorySystem system) throws IOException {
        DefaultRepositorySystemSession session = MavenRepositorySystemUtils.newSession();
            
        LocalRepository localRepo = new LocalRepository(tempDirectory.toString());
        session.setLocalRepositoryManager(system.newLocalRepositoryManager(session, localRepo));

        session.setTransferListener(new ConsoleTransferListener());
        session.setRepositoryListener(new ConsoleRepositoryListener());

        // uncomment to generate dirty trees
        session.setDependencyGraphTransformer( null );

        return session;
    }

//    static public class NoopHostnameVerifier implements HostnameVerifier {
//
//        public static final NoopHostnameVerifier INSTANCE = new NoopHostnameVerifier();
//
//        @Override
//        public boolean verify(final String s, final SSLSession sslSession) {
//            return true;
//        }
//
//        @Override
//        public final String toString() {
//            return "NO_OP";
//        }
//    }
    
    public List<RemoteRepository> newRepositories(RepositorySystem system, RepositorySystemSession session) {
        /*  
        return new ArrayList<RemoteRepository>(Arrays.asList(newCentralRepository()));
        */
        RemoteRepository central = new RemoteRepository.Builder("central", "default", "http://central.maven.org/maven2/").build();

        List<RemoteRepository> ret = new ArrayList<>();
        List<String> repositories = getConfig(QuintessenceConfig.class).getRepositories();
        for (String repository : repositories) {
            System.out.println(repository);
            String[] items = repository.split("::");
            ret.add(new RemoteRepository.Builder(items[0], items[1],items[2]).build());
        }
        return ret;
    }
    private RemoteRepository newCentralRepository() {
        return null;
    }
    /*
    */
    @Override
    public void close() throws IOException {
        this.tempDirectory.delete();
    }

}

==> quintessence-core-0.4.0-sources.jar: net/aequologica/neo/quintessence/aether/Booter.java <==
package net.aequologica.neo.quintessence.aether;

import static net.aequologica.neo.geppaequo.config.ConfigRegistry.getConfig;
import static org.eclipse.aether.repository.RepositoryPolicy.CHECKSUM_POLICY_WARN;
import static org.eclipse.aether.repository.RepositoryPolicy.UPDATE_POLICY_ALWAYS;

import java.io.Closeable;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.maven.repository.internal.MavenRepositorySystemUtils;
import org.eclipse.aether.DefaultRepositorySystemSession;
import org.eclipse.aether.RepositorySystem;
import org.eclipse.aether.RepositorySystemSession;
import org.eclipse.aether.connector.basic.BasicRepositoryConnectorFactory;
import org.eclipse.aether.impl.DefaultServiceLocator;
import org.eclipse.aether.repository.LocalRepository;
import org.eclipse.aether.repository.Proxy;
import org.eclipse.aether.repository.RemoteRepository;
import org.eclipse.aether.repository.RemoteRepository.Builder;
import org.eclipse.aether.repository.RepositoryPolicy;
import org.eclipse.aether.spi.connector.RepositoryConnectorFactory;
import org.eclipse.aether.spi.connector.transport.TransporterFactory;
import org.eclipse.aether.transport.file.FileTransporterFactory;
import org.eclipse.aether.transport.http.HttpTransporterFactory;

import net.aequologica.neo.geppaequo.config.ConfigRegistry;
import net.aequologica.neo.quintessence.aether.utils.ConsoleRepositoryListener;
import net.aequologica.neo.quintessence.aether.utils.ConsoleTransferListener;
import net.aequologica.neo.quintessence.aether.utils.TempDirectory;
import net.aequologica.neo.quintessence.config.QuintessenceConfig;

public class Booter implements Closeable {

    final private TempDirectory tempDirectory;
    
    public Booter() throws IOException {
        super();
        this.tempDirectory = new TempDirectory("local-repo");
    }

    public RepositorySystem newRepositorySystem() {
        /*
         * Aether's components implement org.eclipse.aether.spi.locator.Service
         * to ease manual wiring and using the prepopulated
         * DefaultServiceLocator, we only need to register the repository
         * connector and transporter factories.
         */
        DefaultServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        locator.addService(RepositoryConnectorFactory.class, BasicRepositoryConnectorFactory.class);
        locator.addService(TransporterFactory.class, FileTransporterFactory.class);
        locator.addService(TransporterFactory.class, HttpTransporterFactory.class);

        locator.setErrorHandler(new DefaultServiceLocator.ErrorHandler() {
            @Override
            public void serviceCreationFailed(Class<?> type, Class<?> impl, Throwable exception) {
                exception.printStackTrace();
            }
        });

        return locator.getService(RepositorySystem.class);
    }    

    public DefaultRepositorySystemSession newRepositorySystemSession(RepositorySystem system) throws IOException {
        DefaultRepositorySystemSession session = MavenRepositorySystemUtils.newSession();
            
        LocalRepository localRepo = new LocalRepository(tempDirectory.toString());
        session.setLocalRepositoryManager(system.newLocalRepositoryManager(session, localRepo));

        session.setTransferListener(new ConsoleTransferListener());
        session.setRepositoryListener(new ConsoleRepositoryListener());

        // uncomment to generate dirty trees
        session.setDependencyGraphTransformer( null );

        return session;
    }

    public List<RemoteRepository> newRepositories(RepositorySystem system, RepositorySystemSession session) {
        List<RemoteRepository> ret = new ArrayList<>();

        QuintessenceConfig cfg = ConfigRegistry.getConfig(QuintessenceConfig.class);
        Proxy proxy = null;
        if (cfg.getProxyHost() != null && !cfg.getProxyHost().isEmpty()) {
            proxy = new Proxy(null, cfg.getProxyHost(), cfg.getProxyPort());
        }
        
        /*
        Builder centralBuilder = new RemoteRepository.Builder("central", "default", "http://repo1.maven.org/maven2/");

        RemoteRepository central = null;
        if (proxy != null) {
            central = centralBuilder.setProxy(proxy).build();
        } else {
            central = centralBuilder.build();
        }
        ret.add(central);
        */
        
        List<String> repositories = getConfig(QuintessenceConfig.class).getRepositories();
        for (String repository : repositories) {
            System.out.println(repository);
            String[] items = repository.split("::");
            Builder builder = new RemoteRepository.Builder(items[0], items[1], items[2]).setPolicy(new RepositoryPolicy(true, UPDATE_POLICY_ALWAYS, CHECKSUM_POLICY_WARN));
            if (proxy != null) {
                ret.add(builder.setProxy(proxy).build());
            } else {
                ret.add(builder.build());
            }
        }
        return ret;
    }

    @Override
    public void close() throws IOException {
        this.tempDirectory.delete();
    }

}
